@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-VERSION = (0, 2, 0)
+VERSION = (0, 3, 0)
 PRERELEASE = None  # alpha, beta or rc
 REVISION = None
 
@@ -15,7 +15,7 @@ def generate_version(version, prerelease=None, revision=None):
 
 
 __title__ = "present"
-__description__ = "A terminal-based presentation tool."
+__description__ = "A terminal presentation tool with colors and effects."
 __url__ = "https://github.com/vinayak-mehta/present"
 __version__ = generate_version(VERSION, prerelease=PRERELEASE, revision=REVISION)
 __author__ = "Vinayak Mehta"
